# -*- coding: utf-8 -*-
__author__ = """Ilya Sukhanov"""
__email__ = "ilya@sukhanov.net"
__version__ = "0.1.0"

from lambda_requests.lambda_request import (  # noqa
    DEFAULT_SCHEME,
    LambdaAdapter,
    Session,
)
